%define anolis_release 3
%define upstream_version %(echo %{version} | sed -e 's/\\./-/g')

Name: lm_sensors
Version: 3.6.0
Release: %{anolis_release}%{?dist}
Summary: Hardware monitoring tools
License: GPLv2+ and Verbatim and MIT
URL: http://github.com/lm-sensors/lm-sensors/

Source0: https://github.com/lm-sensors/lm-sensors/archive/V%{upstream_version}/lm-sensors-%{upstream_version}.tar.gz
Source1: lm_sensors.sysconfig
# This one was taken from PLD-linux, Thanks!
Source2: sensord.sysconfig
Source3: lm_sensors-modprobe-wrapper
Source4: lm_sensors-modprobe-r-wrapper
Source5: sensord.service
Source6: sensord-service-wrapper
Source7: lm_sensors.service
Source8: lm_sensors-wrapper

# Downstream-only:
Patch0: 0001-Revert-unnecessary-soname-bump.patch

# Upstream patch:
Patch1: 0001-Change-PIDFile-path-from-var-run-to-run.patch
Patch2: lm_sensors-3.6.0-allow_no_sensors.patch
# Upstream commit 5deee7d0c301df779:
Patch3: lm_sensors-3.6.0-sensors-detect-Add-support-for-AMD-CPU-Family-19h.patch

Requires: /usr/sbin/modprobe
%ifarch x86_64
Requires: /usr/sbin/dmidecode
%endif
Requires: %{name}-libs = %{version}-%{release}
Requires(post): systemd-units
BuildRequires: kernel-headers >= 2.2.16, bison, flex, gawk
BuildRequires: perl-generators
BuildRequires: rrdtool-devel
BuildRequires: gcc
BuildRequires: make


%description
The lm_sensors package includes a collection of modules for general SMBus
access and hardware monitoring.


%package doc
Summary:        Documentation files for %{name}
Requires:       %{name} = %{version}-%{release}
BuildArch:      noarch

%description    doc
The %{name}-doc package contains documentation files for %{name}.

%package libs
Summary: Lm_sensors core libraries
License: LGPLv2+

%description libs
Core libraries for lm_sensors applications


%package devel
Summary: Development files for programs which will use lm_sensors
Requires: %{name}-libs = %{version}-%{release}
# One manual page is licensed Verbatim (lib/libsensors.3). The rest is LGPLv2+.
License: LGPLv2+ and Verbatim

%description devel
The lm_sensors-devel package includes a header files and libraries for use
when building applications that make use of sensor data.


%package sensord
Summary: Daemon that periodically logs sensor readings
Requires: %{name} = %{version}-%{release}
Requires: %{name}-libs = %{version}-%{release}
# One man page is licensed Verbatim (prog/sensord/sensord.8). Files from
# dist-git are licensed MIT according to the FPCA. The rest is GPLv2+.
License: GPLv2+ and Verbatim and MIT

%description sensord
Daemon that periodically logs sensor readings to syslog or a round-robin
database, and warns of sensor alarms.


%prep
%autosetup -n lm-sensors-%{upstream_version} -p1

# Remove currently unused files to make sure we've got the license right
rm -f prog/init/sysconfig-lm_sensors-convert prog/hotplug/unhide_ICH_SMBus

mv prog/init/README prog/init/README.initscripts
chmod -x prog/init/fancontrol.init

# fixing the sensord-service-wrapper path
cp -p %{SOURCE5} sensord.service
cp -p %{SOURCE7} lm_sensors.service
sed -i "s|\@WRAPPER_DIR\@|%{_libexecdir}/%{name}|" sensord.service
sed -i "s|\@WRAPPER_DIR\@|%{_libexecdir}/%{name}|" lm_sensors.service


%build
%set_build_flags
%{make_build} PREFIX=%{_prefix} LIBDIR=%{_libdir} MANDIR=%{_mandir} \
  EXLDFLAGS="$LDFLAGS" PROG_EXTRA=sensord BUILD_STATIC_LIB=0 user


%install
make PREFIX=%{_prefix} LIBDIR=%{_libdir} MANDIR=%{_mandir} PROG_EXTRA=sensord \
  DESTDIR=$RPM_BUILD_ROOT BUILD_STATIC_LIB=0 user_install

ln -s sensors.conf.5.gz $RPM_BUILD_ROOT%{_mandir}/man5/sensors3.conf.5.gz

mkdir -p $RPM_BUILD_ROOT%{_initrddir}
mkdir -p $RPM_BUILD_ROOT%{_sysconfdir}/sensors.d
mkdir -p $RPM_BUILD_ROOT%{_sysconfdir}/sysconfig
install -pm 644 %{SOURCE1} $RPM_BUILD_ROOT%{_sysconfdir}/sysconfig/lm_sensors
install -pm 644 %{SOURCE2} $RPM_BUILD_ROOT%{_sysconfdir}/sysconfig/sensord

# service files
mkdir -p $RPM_BUILD_ROOT%{_unitdir}
install -pm 644 prog/init/fancontrol.service $RPM_BUILD_ROOT%{_unitdir}
install -pm 644 lm_sensors.service           $RPM_BUILD_ROOT%{_unitdir}
install -pm 644 sensord.service              $RPM_BUILD_ROOT%{_unitdir}

# customized modprobe calls
mkdir -p $RPM_BUILD_ROOT%{_libexecdir}/%{name}
install -pm 755 %{SOURCE3} $RPM_BUILD_ROOT%{_libexecdir}/%{name}/lm_sensors-modprobe-wrapper
install -pm 755 %{SOURCE4} $RPM_BUILD_ROOT%{_libexecdir}/%{name}/lm_sensors-modprobe-r-wrapper
install -pm 755 %{SOURCE8} $RPM_BUILD_ROOT%{_libexecdir}/%{name}/lm_sensors-wrapper

# sensord service wrapper
install -pm 755 %{SOURCE6} $RPM_BUILD_ROOT%{_libexecdir}/%{name}/sensord-service-wrapper

%generate_compatibility_deps

# Note non standard systemd scriptlets, since reload / stop makes no sense
# for lm_sensors
%triggerun -- lm_sensors < 3.3.0-2
if [ -L /etc/rc3.d/S26lm_sensors ]; then
    /bin/systemctl enable lm_sensors.service >/dev/null 2>&1 || :
fi
/sbin/chkconfig --del lm_sensors

# ===== main =====

%post
%systemd_post lm_sensors.service

%preun
%systemd_preun lm_sensors.service

%postun
%systemd_postun_with_restart lm_sensors.service

# ==== sensord ===

%post sensord
%systemd_post sensord.service

%preun sensord
%systemd_preun sensord.service

%postun sensord
%systemd_postun_with_restart sensord.service

# ===== libs =====

%ldconfig_scriptlets libs


%files
%license COPYING
%doc prog/init/fancontrol.init prog/init/README.initscripts
%config %{_sysconfdir}/sensors3.conf
%config(noreplace) %{_sysconfdir}/sysconfig/lm_sensors
%dir %{_sysconfdir}/sensors.d
%{_bindir}/*
%{_mandir}/man1/*
%{_mandir}/man5/*
%{_mandir}/man8/*
%{_sbindir}/*
%{abidir}/*-option.list
%{_unitdir}/lm_sensors.service
%{_unitdir}/fancontrol.service
%dir %{_libexecdir}/%{name}
%{_libexecdir}/%{name}/lm_sensors-modprobe*wrapper
%{_libexecdir}/%{name}/lm_sensors-wrapper
%exclude %{_sbindir}/sensord
%exclude %{_mandir}/man8/sensord.8.gz

%files doc
%doc CHANGES CONTRIBUTORS doc README*

%files libs
%dir %{abidir}
%{_libdir}/*.so.*
%{abidir}/*.dump
%license COPYING.LGPL

%files devel
%{_includedir}/sensors
%{_libdir}/lib*.so
%{_mandir}/man3/*

%files sensord
%doc prog/sensord/README
%{_sbindir}/sensord
%{_mandir}/man8/sensord.8.gz
%config(noreplace) %{_sysconfdir}/sysconfig/sensord
%{_unitdir}/sensord.service
%{_libexecdir}/%{name}/sensord-service-wrapper


%changelog
* Wed Nov 02 2022 mgb01105731 <mgb01105731@alibaba-inc.com> - 3.6.0-3
- optimise spec file

* Sat Oct 08 2022 mgb01105731 <mgb01105731@alibaba-inc.com> - 3.6.0-2
- add doc package

* Fri Jul 15 2022 happy_orange <songnannan@linux.alibaba.com> - 3.6.0-1
- Init pacakge from upstream
